Struct diem_logger::sample::Sampling [−][src]
pub struct Sampling { /* fields omitted */ }Expand description
An internal struct that can be checked if a sample is ready for the sample! macro
pub struct Sampling { /* fields omitted */ }An internal struct that can be checked if a sample is ready for the sample! macro